==> core-io-1.0.0-sources.jar: com/couchbase/client/core/ReplicaNotConfiguredException.java <==
/**
 * Copyright (C) 2014 Couchbase, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALING
 * IN THE SOFTWARE.
 */
package com.couchbase.client.core;

public class ReplicaNotConfiguredException extends CouchbaseException {

    public ReplicaNotConfiguredException() {
    }

    public ReplicaNotConfiguredException(String message) {
        super(message);
    }

    public ReplicaNotConfiguredException(String message, Throwable cause) {
        super(message, cause);
    }

    public ReplicaNotConfiguredException(Throwable cause) {
        super(cause);
    }
}

==> core-io-1.2.3-sources.jar: com/couchbase/client/core/ReplicaNotConfiguredException.java <==
/**
 * Copyright (C) 2014 Couchbase, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALING
 * IN THE SOFTWARE.
 */
package com.couchbase.client.core;

/**
 * This exception is thrown when the given operation targeting a specific replica is not fulfillable because the
 * replica is not configured (for example replica 2 is asked for, but only 1 is configured).
 *
 * @author Michael Nitschinger
 * @since 1.0.0
 */
public class ReplicaNotConfiguredException extends CouchbaseException {

    public ReplicaNotConfiguredException() {
    }

    public ReplicaNotConfiguredException(String message) {
        super(message);
    }

    public ReplicaNotConfiguredException(String message, Throwable cause) {
        super(message, cause);
    }

    public ReplicaNotConfiguredException(Throwable cause) {
        super(cause);
    }
}
